@@ -24,7 +24,7 @@ fortify.igraph <- function(
   ...
 ) {
   # node placement
-  if (inherits(layout, "matrix") && identical(dim(layout), c(igraph::gorder(model), 2L))) {
+  if (inherits(layout, "matrix") && identical(dim(layout), c(as.integer(igraph::gorder(model)), 2L))) {
     nodes <- layout[, 1:2 ]
   } else if (inherits(layout, "matrix")) {
     stop("layout matrix dimensions do not match network size")
